##  If Applicable: Additional Features and Views Leveraging SAP Reference Data
SAP LeanIX is part of the SAP ecosystem and provides the option for SAP customers to leverage SAP reference data helping you accelerate the journey. Below, you can see some illustrative report views that you can create based on that reference data to display your current vs. target business architecture.
Example report view: Start with SAP Reference Architecture or compare to current Business Capabilities.
![Business Capability Reference Architecture Comparison](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749483c7a441014946bd9b2dfa0b92a_LowRes.png)
Business Capability Reference Architecture Comparison
Example report view: Understand how Business Capabilities can be supported by current Applications and by Recommendations from the SAP Reference Architecture:
![Application Landscape Report with Reference Architecture](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f9a607a441014a8d2af59b3d23390_LowRes.png)
Application Landscape Report with Reference Architecture
